<template>
  <basic-container>
    <v-chart id="chart" :auto-resize="true" :options="chartOptions"></v-chart>
    <div style="display: inline-block;float: right;margin-bottom: 10px;margin-right: 60px">
      <el-button size="small" type="danger" plain @click="delHandler">删除</el-button>
    </div>
  </basic-container>
</template>

<script>
import echarts from'echarts'
import 'echarts/lib/chart/line'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'
import 'echarts/lib/component/legend'
import {deleteChartId} from "@/api/statistic/chart"

export default {
  name: "stackedAreaChart",
  props: {
    mixData: {
      type: Array,
      default: []
    },
    chartName: {
      type: String,
      default: ""
    },
    btmname :{
      type: String
    }
  },
  data() {
    return {
      chartOptions: {
        color: ['#84C9E5', '#F68686'],
        title: {
          text: '',
        },
        grid: {
          left: "3%",
          right: "4%",
          bottom: "3%",
          containLabel: true,
        },
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "cross"
          }
        },
        legend: {
          data: ['总量', '新增']
        },
        xAxis: {
          type: "category",
          boundaryGap: false,
          data: [
            "一月",
            "二月",
            "三月",
            "四月",
            "五月",
            "六月",
            "七月",
            "八月",
            "九月",
            "十月",
            "十一月",
            "十二月",
          ],
        },
        yAxis: {
          type: "value",
        },
        series: [

        ]
      }
    };
  },
  watch: {
    mixData: {
      immediate: true,
      handler(newval, oldval) {
        if (newval) {
          const series = newval.map((data, index) => ({
            name: index === 0 ? '总量' : '新增',
            type: 'line',
            showSymbol: false,//是否显示折线上的标记点
            smooth: true,//平滑度
            areaStyle: {
              opacity: 1, //透明度
            },
            emphasis: {
              focus: 'series'
            },
            stack: index === 0 ? '总量' : '新增', // 根据 index 区分总量和新增的堆叠情况
            data: data.map(value => ({value})),
            label: {
              show: true,
              position: 'top'
            },
          }));

          this.chartOptions.series = series;
        }
      }
    },
    chartName: {
      handler(newval, oldval) {
        if (newval) {
          this.chartOptions.title.text = newval + "数据统计"
        }
      },
      immediate: true,
      deep: true
    }
  },
  methods:{
    delHandler(){
      deleteChartId({btmname:this.btmname,chartId:'3'}).then(res=>{
        this.$message.success(this.chartName+'堆叠折线图，删除成功！')
        this.$emit('refresh');
      }).catch(error=>{
        this.$message.error(error)
      })
    }
  }
};
</script>

<style scoped lang="scss">
#chart {
  width: 100%;
  height: 560px;
}
</style>
